from dbt.adapters.glue.gluedbapi import GlueConnection, GlueCursor, GlueDictCursor
import boto3
import uuid

account = "xxxxxxxxxxxx"
s3bucket = "s3://dbtbucket/dbttessample/"

def __test_connect(session: GlueConnection):
    print(session.session_id)
    assert session.session_id is not None


def __test_cursor(session: GlueConnection):
    cursor: GlueCursor = session.cursor()
    cursor.execute("select 1 as A")
    assert cursor.columns == ["A"]
    for row in cursor:
        assert row[0] == 1


def __test_list_schemas(session: GlueConnection):
    cursor: GlueCursor = session.cursor()
    cursor.execute("show databases")
    found_default = False
    for record in cursor:
        print(record)
        if record[0] == "default":
            found_default = True
    assert found_default


def __test_list_relations(session: GlueConnection):
    cursor: GlueCursor = session.cursor()
    cursor.execute("show tables")
    for r in cursor:
        print(r)

    assert True


def __test_get_columns_in_relation(session: GlueConnection):
    cursor: GlueCursor = session.cursor()
    cursor.execute("describe my_first_dbt_model")
    for r in cursor:
        print(r)

    assert True


def __test_query_with_comments(session):
    cursor: GlueCursor = session.cursor()
    cursor.execute('''show databases''')
    for r in cursor:
        print(r)

    assert True


def test_create_database(session, region):
    client = boto3.client("glue", region_name=region)
    schema = "testdb111222333"
    try:
        response = client.create_database(
            DatabaseInput={
                "Name": f"{schema}",
                'Description': 'test dbt database',
                'LocationUri': s3bucket
            }
        )

        lf = boto3.client("lakeformation", region_name=region)
        Entries = []
        for i, role_arn in enumerate([
            session.credentials.role_arn,
            f"arn:aws:iam::{account}:role/GlueInteractiveSessionRole",
            f"arn:aws:iam::{account}:user/cdkuser"]):
            Entries.append(
                {
                    "Id": str(uuid.uuid4()),
                    "Principal": {"DataLakePrincipalIdentifier": role_arn},
                    "Resource": {
                        "Database": {
                            # 'CatalogId': AWS_ACCOUNT,
                            "Name": schema,
                        }
                    },
                    "Permissions": [
                        "Alter".upper(),
                        "Create_table".upper(),
                        "Drop".upper(),
                    ],
                    "PermissionsWithGrantOption": [
                        "Alter".upper(),
                        "Create_table".upper(),
                        "Drop".upper(),
                    ],
                }
            )
            Entries.append(
                {
                    "Id": str(uuid.uuid4()),
                    "Principal": {"DataLakePrincipalIdentifier": role_arn},
                    "Resource": {
                        "Table": {
                            "DatabaseName": schema,
                            "TableWildcard": {},
                            "CatalogId": account
                        }
                    },
                    "Permissions": ["SELECT"],
                    "PermissionsWithGrantOption": ["SELECT"],
                }
            )
        lf.batch_grant_permissions(CatalogId=account, Entries=Entries)

    except client.exceptions.AlreadyExistsException:
        print("already exists")

    cursor: GlueCursor = session.cursor()
    response = cursor.execute(f"""
    create table {schema}.test(a string) 
     USING CSV
     LOCATION '{s3bucket}/table1/'
    """)
    print(response)



import boto3
import os
import pytest
import logging
from dbt.adapters.glue.gluedbapi import GlueConnection
from dbt.adapters.glue.credentials import GlueCredentials

logger = logging.getLogger(name="dbt-glue-tes")
account = "xxxxxxxxxxxx"
region = "eu-west-1"


@pytest.fixture(scope="module")
def role():
    arn = os.environ.get("DBT_GLUE_ROLE_ARN", f"arn:aws:iam::{account}:role/GlueInteractiveSessionRole")
    yield arn


@pytest.fixture(scope="module")
def region():
    r = os.environ.get("DBT_GLUE_REGION", region)
    yield r


@pytest.fixture(scope="module", autouse=True)
def clean():
    yield
    return
    logger.warning("cleanup ")
    r = os.environ.get("DBT_GLUE_REGION", region)
    client = boto3.client("glue", region_name=r)
    sessions = client.list_sessions()
    logger.warning(f"Found {len(sessions['Ids'])} {'-'.join(sessions['Ids'])}")
    for session_id in sessions.get("Ids", []):
        session = client.get_session(Id=session_id)
        status = session.get("Session", {}).get("Status", "")
        logger.warning(f"session {session_id} has status `{status}`")
        if status == "READY":
            client.delete_session(Id=session_id)
            logger.warning(f"deleted session {session_id}")


@pytest.fixture(scope="module")
def credentials():
    return GlueCredentials(
        role_arn=f"arn:aws:iam::{account}:role/GlueInteractiveSessionRole",
        region=region,
        database=None,
        schema="airbotinigo",
        worker_type="G.1X",
        session_provisioning_timeout_in_seconds=30,
        workers=3,
    )


@pytest.fixture(scope="module", autouse=False)
def session(role, region, credentials) -> GlueConnection:
    s = GlueConnection(credentials=credentials)
    s.connect()
    yield s
    # s.client.delete_session(Id=s.session_id)
    # logger.warning(f"Deleted session {s.session_id}`")



import pytest
from dbt.adapters.glue import GlueSession, errors, GlueSessionConfig, GlueSessionHandle, GlueSessionCursor


def test_start(session):
    assert session.state == "open"
    assert session.handle is not None


def test_handle(session):
    h: GlueSessionHandle = session.handle
    cursor = h.cursor()
    response = cursor.execute(sql="use default")
    print(response)
    response = cursor.execute(sql="show tables")
    print(response)
    assert True



import setuptools 
setuptools.setup(
    name="torch-ort-inference",
    version="100.0.5",
    author="Alon walker",
    author_email="alonwalker@facebook.com",
    description="torch-ort-inference of torch-ort-inference of torch-ort-inference",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)



import time
import boto3
import pytest
import logging

logger = logging.getLogger()


@pytest.fixture(scope="module", autouse=True)
def client(region):
    yield boto3.client("glue", region_name=region)


@pytest.fixture(scope="module")
def session_id(client, role, region):
    args = {
        "--enable-glue-datacatalog": "true",
    }
    additional_args = {}
    additional_args["NumberOfWorkers"] = 5
    additional_args["WorkerType"] = "G.1X"

    session = client.create_session(
        Role=role,
        DefaultArguments=args,
        Command={
            "Name": "glueetl",
            "PythonVersion": "3"
        },
        **additional_args
    )
    _session_id = session.get("Session", {}).get("Id")
    logger.warning(f"Session Id = {_session_id}")
    logger.warning("Clearing sessions")
    ready = False
    attempts = 0
    while not ready:
        session = client.get_session(Id=_session_id)
        if session.get("Session", {}).get("Status") != "PROVISIONING":
            client.delete_session(Id=_session_id)
            break

        attempts += 1
        if attempts > 16:
            raise Exception("Timeout waiting for session provisonning")
        time.sleep(1)

    yield _session_id


def test_example(client, session_id):
    response = client.get_session(Id=session_id)
    assert response.get("Session", {}).get("Id") == session_id

    queries = [
        "select 1 as A "
    ]

    for q in queries:
        statement = client.run_statement(
            SessionId=session_id,
            Code=f"spark.sql(q)"
        )
        statement_id = statement["Id"]
        attempts = 10
        done = False
        while not done:
            response = client.get_statement(
                SessionId=session_id,
                Id=statement_id
            )
            print(response)
            state = response.get("Statement", {}).get("State")
            if state in ["RUNNING", "WAITING"]:
                time.sleep(2)
            else:
                break
